==> pc2m-0.9.2.zip: pc2m-0.9.2/ErrorMessages.inc.php <==
<?php

/* ------------------------------------------------------------------------
	!!!This file must be in EUC-JP!!!

	顼å
	for PC2M Webpage Converter for Mobile Clients
	Copyright (C) 2005 ucb@rcdtokyo.com http://www.rcdtokyo.com/pc2m/note/

	åʸ桢{%}ʬϡ顼Ƥ˱֤
	ǤפǤкƤޤäƤ⺹٤ޤ
------------------------------------------------------------------------ */

return array(

	'ERROR_FRONTPAGE_MISSING'	=> 'Frontpage.inc.phpɤ߹ߤ˼ԤDEFAULT_URLƤʤConfig.inc.phpɤ߹ߤ˼Ԥޤ',

	'ERROR_ARG_INVALID'			=> 'ꥯƤϰϳ',
	'ERROR_URL_INVALID'			=> '{%1}̵URLäݤ',
	'ERROR_URL_EMPTY'			=> 'URLꤵƤޤ',
	'ERROR_SCHEME_UNSUPPORTED'	=> '{%1}ǻϤޤURLѤǤޤ',
	'ERROR_SSL_DISABLED'		=> 'ΥץȤưƤ륵ФSSL̿ǽ餷Τǡ<a href="{%1}">{%1}</a>ˤ³Ǥޤ',
	'ERROR_WORD_NOTFOUND'		=> '{%1}Ĥޤ',

	'ERROR_SERVER_NORESPONSE'	=> '<a href="{%1}">{%1}</a>ʤ櫓ǡФĤʤȤDNS顼ȤʤȻפ',
	'ERROR_CLENGTH_EXCEEDED'	=> '<a href="{%1}">{%1}</a>Content-Length({%2}bytes)ϰ({%3}bytes)ĶƤޤ',
	'ERROR_CTYPE_INVALID'		=> '<a href="{%1}">{%1}</a>Υե{%2}פѴоݳǤüηбƤȻפľܳƤߤƤ',

	'ERROR_XML_PARSEFAILED'		=> 'XMLʸβϤ˼ԤͤǤ<a href="{%1}">{%1}</a>ŬڤXMLʸǤϤʤΤ⤷ޤ{%2}',
	'ERROR_RSS_INVALID'			=> 'XMLʸ<a href="{%1}">{%1}</a>RSSեɤȤƲϤ褦ȤƼԤͤǤŬڤRSSեɤǤϤʤPEAR::XML_RSSݡȤƤʤʤΤ⤷ޤ',
	'ERROR_CONTENT_EMPTY'		=> 'Ƥʤ͡ͰʲβJavaScriptΤߤȤ',

	'ERROR_CACHESIZE_TOOSMALL'	=> 'üΥå奵()᤮Τǡɽߤޤ',
	'ERROR_DIVPOINT_OUTRANGE'	=> 'ɽϰ֤Ȥƻꤵ줿ʸ({%1})ڡʸ({%2})ĶƤꤷޤ',

	'ERROR_COLOR_INCAPABLE'		=> 'üǤϲɽϹԤޤ',
	'ERROR_PIXSIZE_OUTRANGE'	=> 'ϽĲ줾640ʲǻꤷƤ',
	'ERROR_ISNOT_IMAGE'			=> '<a href="{%1}">{%1}</a>βμ˼Ԥ͡¤ϲʤȤRefererʤɤǥ¤ƤȤ',
	'ERROR_UNSUPPORTED_IMAGE'	=> '<a href="{%1}">{%1}</a>GIF/JPEG/PNGʳ',
);

?>

==> pc2m-0.9.3.zip: pc2m-0.9.3/ErrorMessages.inc.php <==
<?php

/* ------------------------------------------------------------------------
	!!!This file must be in EUC-JP!!!

	顼å
	for PC2M Web Contents Converter for Mobile Clients
	Copyright (C) 2005 ucb@rcdtokyo.com http://www.rcdtokyo.com/pc2m/note/

	åʸ桢{%}ʬϡ顼Ƥ˱֤
	ǤפǤкƤޤäƤ⺹٤ޤ
------------------------------------------------------------------------ */

return array(

	'ERROR_FRONTPAGE_MISSING'	=> 'Frontpage.inc.phpɤ߹ߤ˼ԤDEFAULT_URLƤʤConfig.inc.phpɤ߹ߤ˼Ԥޤ',

	'ERROR_ARG_INVALID'			=> 'ꥯƤϰϳ',
	'ERROR_URL_INVALID'			=> '{%1}̵URLäݤ',
	'ERROR_URL_EMPTY'			=> 'URLꤵƤޤ',
	'ERROR_SCHEME_UNSUPPORTED'	=> '{%1}ǻϤޤURLѤǤޤ',
	'ERROR_SSL_DISABLED'		=> 'ΥץȤưƤ륵ФSSL̿ǽ餷Τǡ<a href="{%1}">{%1}</a>ˤ³Ǥޤ',
	'ERROR_WORD_NOTFOUND'		=> '{%1}Ĥޤ',

	'ERROR_SERVER_NORESPONSE'	=> '<a href="{%1}">{%1}</a>ʤ櫓ǡФĤʤȤDNS顼ȤʤȻפ',
	'ERROR_CLENGTH_EXCEEDED'	=> '<a href="{%1}">{%1}</a>Content-Length({%2}bytes)ϰ({%3}bytes)ĶƤޤ',
	'ERROR_CTYPE_INVALID'		=> '<a href="{%1}">{%1}</a>Υե{%2}פѴоݳǤüηбƤȻפľܳƤߤƤ',

	'ERROR_XML_PARSEFAILED'		=> 'XMLʸβϤ˼ԤͤǤ<a href="{%1}">{%1}</a>ŬڤXMLʸǤϤʤΤ⤷ޤ{%2}',
	'ERROR_RSS_INVALID'			=> 'XMLʸ<a href="{%1}">{%1}</a>RSSեɤȤƲϤ褦ȤƼԤͤǤŬڤRSSեɤǤϤʤPEAR::XML_RSSݡȤƤʤʤΤ⤷ޤ',
	'ERROR_CONTENT_EMPTY'		=> 'Ƥʤ͡ͰʲβJavaScriptΤߤȤ',

	'ERROR_CACHESIZE_TOOSMALL'	=> 'üΥå奵()᤮Τǡɽߤޤ',
	'ERROR_DIVPOINT_OUTRANGE'	=> 'ɽϰ֤Ȥƻꤵ줿ʸ({%1})ڡʸ({%2})ĶƤꤷޤ',

	'ERROR_COLOR_INCAPABLE'		=> 'üǤϲɽϹԤޤ',
//	'ERROR_PIXSIZE_OUTRANGE'	=> 'ϽĲ줾{%1}ʲǻꤷƤ',
	'ERROR_ISNOT_IMAGE'			=> '<a href="{%1}">{%1}</a>βμ˼Ԥ͡¤ϲʤȤRefererʤɤǥ¤ƤȤ',
	'ERROR_UNSUPPORTED_IMAGE'	=> '<a href="{%1}">{%1}</a>GIF/JPEG/PNGʳ',
);

?>
